package checkers.util;

import javax.lang.model.element.Element;
import javax.lang.model.element.Modifier;
import javax.lang.model.element.TypeElement;

/**
 * A Utility class for analyzing {@code Element}s
 * 
 */
public class ElementUtils {

    /**
     * Returns the innermost type element enclosing the given element
     *  
     * @param elem the enclosed element of a class
     * @return  the innermost type element
     */
    public static TypeElement enclosingClass(Element elem) {
        while (elem != null && !elem.getKind().isClass()
                && elem.getKind().isInterface())
            elem = elem.getEnclosingElement();
        return (TypeElement) elem;
    }

    /**
     * Checks if the element is a static element, whether it is a static field, static method, or static class
     * 
     * @param element
     * @return true if element is static
     */
    public static boolean isStatic(Element element) {
        for (Modifier modifier : element.getModifiers()) {
            if (modifier == Modifier.STATIC)
                return true;
        }
        return false;
    }
    
}
